#define WIN32_LEAN_AND_MEAN  

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
#include <objbase.h>
#include <iostream.h> // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>


#include <ddraw.h>     // directX includes
#include <dinput.h>
#include <dsound.h>
#include <dmksctrl.h>
#include <dmusici.h>
#include <dmusicc.h>
#include <dmusicf.h>

#include "T3DLIB1.H"
#include "T3DLIB2.H"
#include "T3DLIB3.H"

#include <vector>
#include <fstream>

// defines for windows 
#define WINDOW_CLASS_NAME "WINCLASS1"

// default screen size
#define SCREEN_WIDTH    640  // size of screen
#define SCREEN_HEIGHT   480
//#define SCREEN_BPP       16  // bits per pixel
#define WINDOWED_APP      0   // 0 = false, 1 = true

#define BITMAP_ID            0x4D42 // universal id for a bitmap
#define MAX_COLORS_PALETTE      256

#define BUTTON_SPRAY			0    // defines for each button
#define BUTTON_PENCIL			1
#define BUTTON_ERASE			2
#define BUTTON_EXIT				3


#define L1_ROWSIZE				4
#define L1_COLSIZE				4
#define L1_MAPSIZE				16
//macro to declare a square 2D vector
#define VECTOR_2D(type) (std::vector<std::vector<type> >)		
#define GRAVITY					0.2
#define CRITTER_GRAVITY			0.2
#define TERMINAL_VELOCITY		5

#define MAX_CRITTER_SPEED		 3
#define MIN_CRITTER_SPEED		-3

#define MAX_ARIANA_SPEED		 4
#define MIN_ARIANA_SPEED		-4
#define LEV1_NUM_TERRAIN_OBJECTS 8
#define LEV1_NUM_WEAPONS		 8
#define LEV1_NUM_BABIES			 1
#define ARIANA_SCALE_FACTOR		 1
#define MEDUSSA_SCALE_FACTOR	0.5
#define MAX_PROJECTILE_SPEED	 8
#define MIN_PROJECTILE_SPEED	-8


#define ARMED				 0x00
#define UNARMED				 0x01
#define WEAPON_AVAILABLE	 0x02
#define WEAPON_UNAVAILABLE	 0x04
#define WEAPON_DESTROYED	 0x08
#define WEAPON_FIRING		 0x10	

enum DIRECTIONS
	{
	NORTH,
	SOUTH,
	EAST,
	WEST,
	SOUTHWEST,
	SOUTHEAST,
	NORTHWEST,
	NORTHEAST,
	JUMPWEST,
	JUMPEAST,
	X
	};

typedef struct VERTICES
	{
	int x;
	int y;
	}VERTEX;

enum vertices 
	{
	V0,
	V1,
	V2,
	V3,
	V4,
	V5,
	V6,
	V7,
	V8,
	V9,
	V10,
	V11,
	V12,
	V13,
	V14,
	V15,
	V16,
	V17,
	V18,
	V19,
	V20,
	V21,
	V22};

typedef enum COLLISION_LOCATIONS
{
	Ce_None,
	Ce_Above,
	Ce_Below,
	Ce_Left,
	Ce_Right
}COLLISION_LOCATION;

typedef struct OBSTACLE
{
	int x;
	int y;
	int width;
	int height;
}OBSTACLE;


typedef enum LEVELS
	{
	MAIN_MENU,
	LEVEL1,
	LEVEL2,
	GAME_OVER,
	CONGRATULATIONS,
	CREDITS
	}LEVEL;

typedef enum 
	{
	SETUP,
	CONTINUE,
	END,
	}FUNCTIONSTAGE;

enum ImageDirection
	{
	BOB_EAST,
	BOB_WEST
	};
/*******************************************************
 Prototypes
********************************************************/
int Game_Init(void *parms=NULL, int num_parms = 0);
int Game_Shutdown(void *parms=NULL, int num_parms = 0);
int Game_Main(void *parms=NULL,  int num_parms = 0);


void CritterAI(BOB* bob, std::vector<std::vector<int> > vMap, std::vector<VERTEX>  vSt_L1_Vertices);
bool Move_Critter(BOB* bob, int  direction);
bool Collision_Checker(BOB* bob, float scale_factor, std::vector<OBSTACLE>);
void WeaponRetrieval(BOB* bob, std::vector<BOB*> vWeapons);
bool IsThereABOBCollision(BOB* pFirstBob, BOB* pSecondBob);


/********************************************************
 Global Variables
********************************************************/
#ifdef GAME_H
	// windows vars
	HWND      main_window_handle = NULL; // globally track main window
	int       window_closed      = 0;    // tracks if window is closed
	HINSTANCE main_instance      = NULL; // globally track hinstance

	char buffer[80];					// used to print text
//	const bool WINDOWED_APP = true;	// 0 = FALSE, 1 = TRUE

	// directinput globals

	// demo globals

//	BITMAP_IMAGE L1_Bmp_BackGrnd; // used to hold playfield
	BITMAP_IMAGE Intro_Text_AjMax;
	BITMAP_IMAGE Intro_Text_Start;
	BITMAP_IMAGE Intro_FlashingBar;
	BITMAP_IMAGE* backgroundImagePtr;

	BOB			L1_Bmp_BackGrnd; // used to hold playfield

	BOB         bat1;         // holds bug blaster
	BOB			Ariana;			
	BOB			Jaden;
	BOB			bat2;
	BOB			Critter2;		 //
	BOB			bobStartExit;
	BOB			explosion;
	BOB			apple1;
	BOB			apple2;
	BOB			apple3;
	BOB			apple4;
	BOB			apple5;
	BOB			apple6;
	BOB			apple7;
	BOB			apple8;
	BOB			jail;
	BOB			smiley;
	BOB			door;
	BOB			banana;
	BOB			baby1;
	BOB			baby2;
	BOB			baby3;
	BOB			baby4;
	BOB			YouWin;
	BOB			clouds;
	BOB			cheese1;
	BOB			cheese2;
	BOB			GameOver;

	BOB*		pTailBaby = &Ariana;
	BOB*		apple1Ptr = &apple1;
	BOB*		apple2Ptr = &apple2;
	BOB*		apple3Ptr = &apple3;
	BOB*		apple4Ptr = &apple4;
	BOB*		apple5Ptr = &apple5;
	BOB*		apple6Ptr = &apple6;
	BOB*		apple7Ptr = &apple7;
	BOB*		apple8Ptr = &apple8;





	BOB*		Critter1Ptr;
	BOB*		Critter2Ptr;

	BOB*		ArianasWeapon = NULL;

	int Ariana_anim_right[4] = {0,1,2,3};
	int Ariana_anim_left[4] = {4,5,6,7};
	int bat1_anim[5] = {0,1,2,3,4};  // blinking animation
	int startExit_anim[2] = {0,1};
	int explosion_anim[8] = {0,1,2,3,4,5,6,7};
	int smiley_anim[3] = {0,1,2};
	int door_anim[4] = {0,1,2,3};

	LEVEL eLevel = MAIN_MENU;

	int midi_ids[10]; // hold storage for 10 songs ids
	int sound_ids[4]; // storage for 4 sound fx ids

	std::vector<BOB*>  vActiveProjectile;
	std::vector<BOB*>  vBabyChain;

	/*********************************************************************************
	Level 1 info
	**********************************************************************************/
/*

v0  v1  v2  v3 
v4  v5  v6  v7 
v8  v9  v10 v11 
v12 v13 v14 v15 
*/

	//This array gives directions how to go from one vertex to another adjacent vertex
/*	int aLevel1_Map[L1_MAPSIZE][L1_MAPSIZE] =	{
													{   X,  WEST,     X,    X},
													{EAST,     X, NORTH,    X},
													{   X, SOUTH,     X, EAST}, 
													{   X,     X,  WEST,    X}};

												//V1         V2        V3         V4
	VERTEX alevel1_VertexLocatons[L1_MAPSIZE] = {{400,300},{300,300},{300,200}, {400,200}};
*/												//V0   V1     V2     V3    V4    V5    V6    V7    V8    V9    V10    V11    V12    V13    V14    V15    
	int aLevel1_Map[L1_MAPSIZE][L1_MAPSIZE] =	{
		//V0   V1      V2      V3      V4       V5      V6     V7      V8      V9      V10    V11      V12      V13    V14     V15    
/*V0*/	{ X,  EAST,	    X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,},	
/*V1*/  { X,	X,JUMPEAST,	 WEST,		X,		X,SOUTHEAST,	X,		X,		X,		X,		X,		X,		X,		X,		X,},	
/*V2*/	{EAST,JUMPWEST,	X,		X,		X,SOUTHWEST,	X,		X,		X,		X,		X,		X,		X,		X,		X,		X,},	
/*V3*/	{ X,    X,	 WEST,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,},	
/*V4*/	{ X,	X,		X,		X,		X,		X,	    X,		X,		X,		X,		X,		X,		X,		X,		X,		X,},	//todo eliminate this row
/*V5*/	{ X,	X,JUMPEAST,		X,		X,		X,	 WEST,	    X,		X,		X,SOUTHEAST,	X,		X,		X,		X,		X,},	
/*V6*/	{ X,JUMPWEST,	X,		X,	    X,	 EAST,		X,		X,		X,SOUTHWEST,	X,		X,		X,		X,		X,		X,},	
/*V7*/	{ X,	X,		X,		X,		X,	    X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,},	//todo eliminate this row
/*V8*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,		X,	    X,		X,		X,		X,		X,		X,},	//todo eliminate this row
/*V9*/	{ X,	X,		X,		X,		X,		X, JUMPEAST,	X,		X,		X,	 WEST,	    X,		X,		X,SOUTHEAST,	X,},	
/*V10*/	{ X,	X,		X,		X,		X,	JUMPWEST,	X,		X,	    X,	 EAST,		X,		X,		X,SOUTHWEST,	X,		X,},	
/*V11*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,	    X,		X,		X,		X,		X,		X,		X,},	//todo eliminate this row
/*V12*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,	 EAST,	    X,		X,},	
/*V13*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,		X,	JUMPEAST,	X,		X,		X,  EAST,	 WEST,},	
/*V14*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,JUMPWEST,		X,		X,	 EAST,   WEST,		X,		X,},	
/*V15*/	{ X,	X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,		X,	    X,	  WEST,		X,}};	

												
VERTEX alevel1_VertexLocatons[L1_MAPSIZE] = {		{240,70},		/*V0 floor 4*/
													{260,70},		/*V1 floor 4*/
													{350,70},		/*V2 floor 4*/
													{380,70},		/*V3 floor 4*/
													{240,180},		/*V4 floor 3*/
													{260,180},		/*V5 floor 3*/
													{350,180},		/*V6 floor 3*/
													{380,180},		/*V7 floor 3*/
													{240,290},		/*V8 floor 2*/
													{260,290},		/*V9 floor 2*/
													{350,290},		/*V10 floor 2*/
													{380,290},		/*V11 floor 2*/
													{240,400},		/*V12 floor 1*/
													{270,400},		/*V13 floor 1*/
													{340,400},		/*V14 floor 1*/
													{380,400},		/*V15 floor 1*/
													};	    



	OBSTACLE alevel1_Terrain[LEV1_NUM_TERRAIN_OBJECTS] = {
														{0,     0, 640,10},	//Sky
														{0,   130, 270,20},	//floor 4
														{370, 130, 270,20},	//floor 4
														{0,   240, 270,20},	//floor 3
														{370, 240, 270,20},	//floor 3
														{0,   350, 270,20},	//floor 2
														{370, 350, 270,20},	//floor 2
														{0, 460, 640,20}}; //ground

	BOB* aLevel_Weapons[LEV1_NUM_WEAPONS] ={apple1Ptr,
											apple2Ptr,
											apple3Ptr,
											apple4Ptr,
											apple5Ptr,
											apple6Ptr,
											apple7Ptr,
											apple8Ptr};

	BOB* aLevel1_babies[LEV1_NUM_BABIES] ={	&baby1/*,
											&baby2,
											&baby3,
											&baby4*/};
	

	//declare 2D vector that will hold map of adjacent point and directions how to get to those points
	std::vector<std::vector<int> > vE_L1_Map(L1_MAPSIZE, std::vector<int> (L1_MAPSIZE));

	//Declare and initialize vector with vertex locations
	std::vector<VERTEX>  vSt_L1_Vertices(alevel1_VertexLocatons, alevel1_VertexLocatons+L1_MAPSIZE);

	//Declare and initialize vector with terrain locations
	std::vector<OBSTACLE>  vSt_L1_Terrain(alevel1_Terrain, alevel1_Terrain+LEV1_NUM_TERRAIN_OBJECTS);

	std::vector<BOB*>  vpSt_L1_Weapons(aLevel_Weapons, aLevel_Weapons+LEV1_NUM_WEAPONS);
	std::vector<BOB*>  vpSt_L1_FreeBabies(aLevel1_babies, aLevel1_babies+LEV1_NUM_BABIES);
	/*********************************************************************************
	Level 2 info
	**********************************************************************************/



#else
	// windows vars
	extern HWND      main_window_handle;	// globally track main window
	extern int       window_closed;		// tracks if window is closed
	extern HINSTANCE main_instance;		// globally track hinstance

	extern char buffer[80];				// used to print text

	extern std::vector<BOB*>  vActiveProjectile;
	extern std::vector<BOB*>  vBabyChain;

//	extern const bool WINDOWED_APP;
	// directinput globals

	// demo globals
//	extern BITMAP_IMAGE L1_Bmp_BackGrnd;       // used to hold playfield
	extern BITMAP_IMAGE Intro_Text_AjMax;
	extern BITMAP_IMAGE Intro_Text_Start;
	extern BITMAP_IMAGE Intro_FlashingBar;

	extern BOB			L1_Bmp_BackGrnd; // used to hold playfield

	extern BOB          bat1;         // holds bug blaster
	extern BOB			Ariana;			
	extern BOB			Jaden;
	extern BOB			bat2;
	extern BOB			Critter2;		 //
	extern BOB			bobStartExit;
	extern BOB			explosion;
	extern BOB			jail;
	extern BOB			smiley;
	extern BOB			door;
	extern BOB			banana;
	extern BOB			baby1;
	extern BOB			baby2;
	extern BOB			baby3;
	extern BOB			baby4;
	extern BOB			YouWin;
	extern BOB			clouds;
	extern BOB			cheese1;
	extern BOB			cheese2;
	extern BOB			GameOver;


	extern BOB			apple1, *apple1Ptr;
	extern BOB			apple2, *apple2Ptr;
	extern BOB			apple3, *apple3Ptr;
	extern BOB			apple4, *apple4Ptr;
	extern BOB			apple5, *apple5Ptr;
	extern BOB			apple6, *apple6Ptr;
	extern BOB			apple7, *apple7Ptr;
	extern BOB			apple8, *apple8Ptr;

	extern BOB*			Critter1Ptr;
	extern BOB*			Critter2Ptr;
	extern BOB*		    ArianasWeapon;
	extern BOB*			pTailBaby;

	extern int Ariana_anim_right[4];
	extern int Ariana_anim_left[4];
	extern int bat1_anim[5];  // blinking animation
	extern int startExit_anim[2];
	extern int explosion_anim[8];
	extern int smiley_anim[3];
	extern int door_anim[4];

	extern LEVEL eLevel;
	extern int midi_ids[10]; // hold storage for 10 songs ids
	extern int sound_ids[4]; // storage for 4 sound fx ids


	/*********************************************************************************
	Level 1 info
	**********************************************************************************/
	extern int aLevel1_Map[L1_MAPSIZE][L1_MAPSIZE]; 
	extern VERTEX alevel1_VertexLocatons[L1_ROWSIZE];
	extern std::vector<std::vector<int> > vE_L1_Map;
	extern std::vector<VERTEX>  vSt_L1_Vertices;
	extern std::vector<OBSTACLE>  vSt_L1_Terrain;
	extern std::vector<BOB*>  vpSt_L1_Weapons;
	extern std::vector<BOB*>  vpSt_L1_FreeBabies;


#endif
