#define WIN32_LEAN_AND_MEAN  

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
#include <objbase.h>
#include <iostream.h> // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>


#include <ddraw.h>     // directX includes
#include <dinput.h>
#include "T3DLIB1.H"
#include "T3DLIB2.H"
#include "Game.h"


//Returns the collision location of rectangle 1 with respect to rectangle 2
//e.g if Ce_Above is returned this means that rectangle 2 is above rectangle 1
//xl1, xl2 is upper left corner x
//yl1, yl2 is upper left corner y
bool Collision_Checker(BOB* bob, float bob_scalar, std::vector<OBSTACLE> obstacles)
{
COLLISION_LOCATION lE_TestStatus = Ce_None;

//////////////////////////////////
// 1) compute the center of x1;
// 2) compute x radius
//
//          |<-xr->|
//  ________|______|__
//  |	  center   | yr
//  |       .______|__
//  |			   | 
//  ----------------
///////////////////////////////////

//Compute Radii
int bob_x_radius  = ((bob_scalar*bob->width)/2.0 + 0.5);
//int bob_y_radius  = ((bob_scalar*bob->height)/2.0 + 0.5);
int bob_y_radius  = ((bob->height)/2.0 + 0.5);

int obstacle_x_radius  = 0;
int obstacle_y_radius  = 0;

//Compute Centers
int bob_x_ctr = bob->x + bob_x_radius;
int bob_y_ctr = bob->y + bob_y_radius;
int obstacle_x_ctr = 0;
int obstacle_y_ctr = 0;



for (std::vector<OBSTACLE>::iterator i = obstacles.begin(); i != obstacles.end();i++)
	{
	//Compute radii
	obstacle_x_radius  = (i->width/2.0 + 0.5);
	obstacle_y_radius  = (i->height/2.0 + 0.5);
	
	//Compute Centers
	obstacle_x_ctr = i->x + obstacle_x_radius; 
	obstacle_y_ctr = i->y + obstacle_y_radius; 

	//is there a collision
	if ((abs(bob_x_ctr-obstacle_x_ctr)>= (bob_x_radius+obstacle_x_radius)) || 
		(abs(bob_y_ctr-obstacle_y_ctr)>= (bob_y_radius+obstacle_y_radius))   )
		{
		lE_TestStatus =  Ce_None;
		}
	else
		{

		//Is rectangle 2 below rectangle 1?
		if((obstacle_y_ctr - bob_y_ctr) > 0 )
			{
			lE_TestStatus = Ce_Below;
			}
		//Is rectangel 1 above rectangle 2? 
		else if ((bob_y_ctr - obstacle_y_ctr) > 0 )
			{
			lE_TestStatus = Ce_Above;
			}
		//Is rectangel 2 right of rectangle 1?
		else if ((obstacle_x_ctr - bob_x_ctr) > 0)
			{
			lE_TestStatus = Ce_Right;
			}
		else
			{//rectangle must be to the right
			lE_TestStatus = Ce_Left;
			}
		}

	if (lE_TestStatus != Ce_None)  //collision found break out of for loop;
		break;
	}//end for loop

//bob->isJumping = false;

//Collision Response
	switch (lE_TestStatus)
	{
	case Ce_None:
		return false;

	case Ce_Below:	
//		bob->y = i->y - bob_scalar*bob->height;	
		bob->y = i->y - bob->height;	
		bob->yv = 0;
		bob->isJumping = false;
		break;

	case Ce_Above:	
		bob->y = i->y + i->height;	
		bob->yv = -bob->yv;

		
/*		bob->yv = -bob->yv;
		bob->yv = 0.05;
*/		break;	

	case Ce_Right:
//		bob->x -= bob->xv;
		bob->xv = -bob->xv;
		break;

	case Ce_Left:	
//		bob->x += bob->xv;
		bob->xv = -bob->xv;				
		break;

	default:
		break;
	}

return true;



}

//todo make this a pointer to a weapon vector??
//this function sets the weapon pointer to an actual weapon if the bob collides with a weapon.
void WeaponRetrieval(BOB* bob, std::vector<BOB*> vWeapons)
{
	if (ArianasWeapon != NULL)
		return;

	if (vWeapons.size() == 0)
		return;

//Compute Radii
int bob_x_radius  = ((/*bob_scalar* */bob->width)/2.0 + 0.5);
//int bob_y_radius  = ((bob_scalar*bob->height)/2.0 + 0.5);
int bob_y_radius  = ((bob->height)/2.0 + 0.5);

int weapon_x_radius  = 0;
int weapon_y_radius  = 0;

//Compute Centers
int bob_x_ctr = bob->x + bob_x_radius;
int bob_y_ctr = bob->y + bob_y_radius;
int weapon_x_ctr = 0;
int weapon_y_ctr = 0;

bool thereIsACollision = false;

for (std::vector<BOB*>::iterator i = vWeapons.begin(); i != vWeapons.end(); i++)
	{
	if ((*i)->weapon_stat == WEAPON_AVAILABLE)
		{
		//Compute radii
		weapon_x_radius  = ((*i)->width/2.0 + 0.5);
		weapon_y_radius  = ((*i)->height/2.0 + 0.5);
	
		//Compute Centers
		weapon_x_ctr = (*i)->x + weapon_x_radius; 
		weapon_y_ctr = (*i)->y + weapon_y_radius; 

		//is there a collision
		if ((abs(bob_x_ctr-weapon_x_ctr)<= (bob_x_radius+weapon_x_radius)) && 
			(abs(bob_y_ctr-weapon_y_ctr)<= (bob_y_radius+weapon_y_radius))   )
			{
			thereIsACollision = true;
			break;	//collision found break out of for loop;
			}
		}

	}//end for loop

if (thereIsACollision == false)
	return;


(*i)->weapon_stat |= WEAPON_UNAVAILABLE;
ArianasWeapon = *i;
}






//this function sets the weapon pointer to an actual weapon if the bob collides with a weapon.
bool IsThereABOBCollision(BOB* pFirstBob, BOB* pSecondBob)
{
	if (pFirstBob->state == BOB_STATE_DEAD || pSecondBob->state == BOB_STATE_DEAD)
		return false;

//Compute Radii
int bob1_x_radius  = ((pFirstBob->width)/2.0 + 0.5);
int bob1_y_radius  = ((pFirstBob->height)/2.0 + 0.5);

int bob2_x_radius  = ((pSecondBob->width)/2.0 + 0.5);
int bob2_y_radius  = ((pSecondBob->height)/2.0 + 0.5);

//Compute Centers
int bob1_x_ctr = pFirstBob->x + bob1_x_radius;
int bob1_y_ctr = pFirstBob->y + bob1_y_radius;
int bob2_x_ctr = pSecondBob->x + bob2_x_radius;
int bob2_y_ctr = pSecondBob->y + bob2_y_radius;



//is there a collision
if ((abs(bob1_x_ctr-bob2_x_ctr)<= (bob1_x_radius+bob2_x_radius)) && 
	(abs(bob1_y_ctr-bob2_y_ctr)<= (bob1_y_radius+bob2_y_radius))   )
	{
	return true;

	}//end for loop

return false;

}
