#define WIN32_LEAN_AND_MEAN  

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
#include <objbase.h>
#include <iostream.h> // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>


#include <ddraw.h>     // directX includes
#include <dinput.h>
#include "T3DLIB1.H"
#include "T3DLIB2.H"
#include "Game.h"
#include <vector>
#include <fstream>

extern std::vector<std::vector<int> > vLevel1_Map;
extern std::ofstream ErrorLog;

void Do_Intro(void);

// GAME PROGRAMMING CONSOLE FUNCTIONS ////////////////

int Game_Init(void *parms,  int num_parms)
{
// this function is where you do all the initialization 
// for your game

int index;         // looping var
char filename[80]; // used to build up files names

/***************************
Initialize Direct Sound 
****************************/

// initialize directsound
DSound_Init();

// initialize directmusic
DMusic_Init();



// load in the digital sound
sound_ids[0] = DSound_Load_WAV("Sound26.WAV");
sound_ids[1] = DSound_Load_WAV("ShldPU.WAV");
sound_ids[2] = DSound_Load_WAV("Beep2.WAV");
sound_ids[3] = DSound_Load_WAV("ammopu.WAV");


// load the midi segments
midi_ids[0] = DMusic_Load_MIDI("midifile9.mid");
midi_ids[1] = DMusic_Load_MIDI("hungdan5.mid");





/*****************************************************************************************
Initialize Direct Draw 
******************************************************************************************/

// initialize directdraw
DDraw_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, WINDOWED_APP);  //SCREEN_FULLSCREEN, SCREEN_WINDOWED

DInput_Init(); //rw
DInput_Init_Joystick(-2, 2, -2, 2, 10); //rw The numbers here specify the step size

//initalize 2d vector with map info
for (int i = 0; i<L1_MAPSIZE; i++)
	{
	for (int j = 0; j< L1_MAPSIZE; j++)
		{
		vE_L1_Map[i][j] = aLevel1_Map[i][j];
		ErrorLog<< vE_L1_Map[i][j] << ' ';
		}
		ErrorLog<< '\n';

	}

/**************
Critter 1 & 2
***************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "Medusa.BMP");		//load image into memory

// now create the bug blaster bob
Create_BOB(&bat1,0,0,40,60,5,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM/*| BOB_ATTR_ANIM_ONE_SHOT*/,
           DDSCAPS_SYSTEMMEMORY, 0, 16);

// load in the four frames of the blaster
for (index=0; index<5; index++)
     Load_Frame_BOB16(&bat1,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct


Create_BOB(&bat2,0,0,40,60,5,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM/*| BOB_ATTR_ANIM_ONE_SHOT*/,
           DDSCAPS_SYSTEMMEMORY, 0, 16);

// load in the four frames of the Critter1
for (index=0; index<5; index++)
     Load_Frame_BOB16(&bat2,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
 

Unload_Bitmap_File(&bitmap16bit);

//////////////////////////////////////////////////

// set the animation sequences for bug blaster
Load_Animation_BOB(&bat1,0,5,bat1_anim);

//initalize  speed
bat1.yv = 0;
bat1.xv = 0;

//animation speed??
bat1.anim_counter = 0;
bat1.anim_count_max = 1000;

// set up starting state of bug blaster
Set_Pos_BOB(&bat1,100,70);
Set_Anim_Speed_BOB(&bat1,3);

bat1.curr_location = bat1.destination = 0;

///////////////////////////////////////////////

Load_Animation_BOB(&bat2,0,5,bat1_anim);
//initalize  speed
bat2.yv = 0;
bat2.xv = 0;

//animation speed??
bat2.anim_counter = 0;
bat2.anim_count_max = 1000;

// set up starting state of bug blaster
Set_Pos_BOB(&bat2,100,400);
Set_Anim_Speed_BOB(&bat2,3);

bat2.curr_location = bat2.destination = 12;






/*****************
Main Character
*****************/
Load_Bitmap_File(&bitmap16bit, "Mouse2.BMP");		//load image into memory


Create_BOB(&Ariana,0,0,29,38,8,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM/*| BOB_ATTR_ANIM_ONE_SHOT*/,
           DDSCAPS_SYSTEMMEMORY, 0, 16);

// load in the frames of the Ariana
for (index=0; index<4; index++)
	{
    Load_Frame_BOB16(&Ariana,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
    Load_Frame_BOB16(&Ariana,&bitmap16bit,index+4,index,1,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
	}
Unload_Bitmap_File(&bitmap16bit);

Load_Animation_BOB(&Ariana,BOB_EAST,4,Ariana_anim_right);
Load_Animation_BOB(&Ariana,BOB_WEST,4,Ariana_anim_left);
Set_Animation_BOB(&Ariana, BOB_WEST);

//initalize  speed
Ariana.yv = 0;
Ariana.xv = 0;

//initialize jumpstatus
Ariana.isJumping = false;



//animation speed??
Ariana.anim_counter = 0;
Ariana.anim_count_max = 1000;

// set up starting state of bug blaster
Set_Pos_BOB(&Ariana,320,20);
Set_Anim_Speed_BOB(&Ariana,3);

Ariana.curr_location = Ariana.destination = 1;


/**********************
Clone the main charater
***********************/
Clone_BOB(&Ariana, &baby1);
Set_Pos_BOB(&baby1,530,200);

Clone_BOB(&Ariana, &baby2);
Set_Pos_BOB(&baby2,50,200);

Clone_BOB(&Ariana, &baby3);
Set_Pos_BOB(&baby3,510,200);

Clone_BOB(&Ariana, &baby4);
Set_Pos_BOB(&baby4,600,310);


/**********
* WEAPONS
***********/

// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "apple.BMP");		//load image into memory

// now create the bug blaster bob
Create_BOB(&apple1,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple2,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple3,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple4,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple5,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple6,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple7,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);
Create_BOB(&apple8,0,0,20,20,1, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&apple1,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple2,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple3,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple4,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple5,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple6,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple7,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Load_Frame_BOB16(&apple8,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct


Unload_Bitmap_File(&bitmap16bit);


//set speed & position
apple1.xv = 0;		apple1.yv = 0;		apple1.x = 100;		apple1.y = 440;		apple1.weapon_stat = WEAPON_AVAILABLE;	
apple2.xv = 0;		apple2.yv = 0;		apple2.x = 100;		apple2.y = 330;		apple2.weapon_stat = WEAPON_AVAILABLE;			
apple3.xv = 0;		apple3.yv = 0;		apple3.x = 100;		apple3.y = 220;		apple3.weapon_stat = WEAPON_AVAILABLE;			
apple4.xv = 0;		apple4.yv = 0;		apple4.x = 100;		apple4.y = 110;		apple4.weapon_stat = WEAPON_AVAILABLE;			
apple5.xv = 0;		apple5.yv = 0;		apple5.x = 540;		apple5.y = 440;		apple5.weapon_stat = WEAPON_AVAILABLE;			
apple6.xv = 0;		apple6.yv = 0;		apple6.x = 540;		apple6.y = 330;		apple6.weapon_stat = WEAPON_AVAILABLE;			
apple7.xv = 0;		apple7.yv = 0;		apple7.x = 540;		apple7.y = 220;		apple7.weapon_stat = WEAPON_AVAILABLE;			
apple8.xv = 0;		apple8.yv = 0;		apple8.x = 540;		apple8.y = 110;		apple8.weapon_stat = WEAPON_AVAILABLE;			



/**************
Explosion
***************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "Explosion.BMP");		//load image into memory

// now create the explosion bob
Create_BOB(&explosion,0,0,100,100,14, BOB_ATTR_VISIBLE |  BOB_ATTR_ANIM_ONE_SHOT|BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY, 0, 16);

// load in the frames of the Ariana
for (index=0; index<4; index++)
	{
    Load_Frame_BOB16(&explosion,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
    Load_Frame_BOB16(&explosion,&bitmap16bit,index+4,index,1,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
	}

Unload_Bitmap_File(&bitmap16bit);

Load_Animation_BOB(&explosion,0,8,explosion_anim);

Set_Anim_Speed_BOB(&explosion, 10);
explosion.anim_state = BOB_STATE_ANIM_DONE;



/**************
Load Jail Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "jail.BMP");		//load image into memory

Create_BOB(&jail,524,164,65,75,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&jail,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);


/**************
Load Cheese Image
**************/
// load the graphics for the 
Load_Bitmap_File(&bitmap16bit, "cheese.BMP");		//load image into memory

Create_BOB(&cheese1,40,70,18,18,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&cheese1,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);

Clone_BOB(&cheese1, &cheese2);
Set_Pos_BOB(&cheese2,40,290);


/**************
Load Level1 Door Image
**************/
// load the graphics for the bat
/*Load_Bitmap_File(&bitmap16bit, "L1_door.BMP");		//load image into memory

Create_BOB(&door,190,330,90,130,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&door,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);
*/

/**************
Load banana Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "bananas.BMP");		//load image into memory

Create_BOB(&banana,50,60,20,19,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&banana,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);


/**************
Load smiley Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "smiley.BMP");		//load image into memory

Create_BOB(&smiley,100,410,78,48,3, BOB_ATTR_VISIBLE |  BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY, 0, 16);

for (index=0; index<3; index++)
	{
    Load_Frame_BOB16(&smiley,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
	}
Unload_Bitmap_File(&bitmap16bit);

Load_Animation_BOB(&smiley,0,3,smiley_anim);
Set_Anim_Speed_BOB(&smiley,10);


/**************
Load door Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "door.BMP");		//load image into memory

Create_BOB(&door,420,390,38,78,4, BOB_ATTR_VISIBLE |  BOB_ATTR_MULTI_ANIM, DDSCAPS_SYSTEMMEMORY, 0, 16);

for (index=0; index<4; index++)
	{
    Load_Frame_BOB16(&door,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
	}
Unload_Bitmap_File(&bitmap16bit);

Load_Animation_BOB(&door,0,4,door_anim);
Set_Anim_Speed_BOB(&door,10);


/**************
Load You Win Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "youWin.BMP");		//load image into memory

Create_BOB(&YouWin,260,230,230,40,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&YouWin,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);


/**************
Game Over Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "GameOver.BMP");		//load image into memory

Create_BOB(&GameOver,40,230,390,64,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&GameOver,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);



/**************
Load Clouds Image
**************/
// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "clouds.BMP");		//load image into memory

Create_BOB(&clouds,0,0,640,480,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME | BOB_ATTR_WRAPAROUND, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&clouds,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);


/***********************************
LOAD backgrounds and setup Clipper
************************************/

// set clipping rectangle to screen extents so objects dont
// mess up at edges
RECT screen_rect = {0,0,screen_width,screen_height};
lpddclipper = DDraw_Attach_Clipper(lpddsback,1,&screen_rect);


Load_Bitmap_File(&bitmap16bit, "Level1.BMP");		//load image into memory

Create_BOB(&L1_Bmp_BackGrnd,0,0,640,480,1, BOB_ATTR_VISIBLE |  BOB_ATTR_SINGLE_FRAME | BOB_ATTR_WRAPAROUND, DDSCAPS_SYSTEMMEMORY, 0, 16);

Load_Frame_BOB16(&L1_Bmp_BackGrnd,&bitmap16bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct
Unload_Bitmap_File(&bitmap16bit);


// create background bitmap for level1
//Create_Bitmap(&L1_Bmp_BackGrnd,0,0,SCREEN_WIDTH,SCREEN_HEIGHT, SCREEN_BPP);
//L1_Bmp_BackGrnd.attr |= BITMAP_ATTR_LOADED;

// fill in the background
//Load_Bitmap_File(&bitmap16bit, "Level1.BMP");

//Set pallete
//Set_Palette(bitmap8bit.palette);				//use the palette that is defined in the .bmp file

// load the grass bitmap image
//Load_Image_Bitmap16(&L1_Bmp_BackGrnd,&bitmap16bit,0,0,BITMAP_EXTRACT_MODE_ABS);
//Unload_Bitmap_File(&bitmap16bit);

// seed random number generator
srand(Start_Clock());

// hide the mouse if now windowed app
if (!WINDOWED_APP)
	{
	ShowCursor(FALSE);
	}


// return success
return(1);

} // end Game_Init




void Do_Intro(void)
{
// the worlds simples intro

// clear out buffers
DDraw_Fill_Surface(lpddsback, 0);
DDraw_Fill_Surface(lpddsprimary, 0);


/////////////////Load title//////////////// 



Create_Bitmap(&Intro_Text_AjMax,0,0,SCREEN_WIDTH,SCREEN_HEIGHT, SCREEN_BPP);
Intro_Text_AjMax.attr |= BITMAP_ATTR_LOADED;

// fill in the background
Load_Bitmap_File(&bitmap16bit, "IntroBackground.bmp");

// load the grass bitmap image
Load_Image_Bitmap16(&Intro_Text_AjMax,&bitmap16bit,0,0,BITMAP_EXTRACT_MODE_ABS);
Unload_Bitmap_File(&bitmap16bit);


/*Create_Bitmap(&Intro_Text_AjMax,0,0,255,80, SCREEN_BPP);


// fill in the background
Load_Bitmap_File(&bitmap16bit, "text_AJMax.bmp");

// load the grass bitmap image
Load_Image_Bitmap16(&Intro_Text_AjMax,&bitmap16bit,0,0,BITMAP_EXTRACT_MODE_ABS);
Unload_Bitmap_File(&bitmap16bit);

Intro_Text_AjMax.attr |= BITMAP_ATTR_LOADED;

// fill in the background
Load_Bitmap_File(&bitmap16bit, "text_AJMax.bmp");

// load the grass bitmap image
Load_Image_Bitmap16(&Intro_Text_AjMax,&bitmap16bit,0,0,BITMAP_EXTRACT_MODE_ABS);
Unload_Bitmap_File(&bitmap16bit);

/////////////////Load start text///////////

Create_Bitmap(&Intro_Text_Start,281,223,80,40, SCREEN_BPP);
Intro_Text_Start.attr |= BITMAP_ATTR_LOADED;

// fill in the background
Load_Bitmap_File(&bitmap16bit, "text_start.bmp");

// load the grass bitmap image
Load_Image_Bitmap16(&Intro_Text_Start,&bitmap16bit,0,0,BITMAP_EXTRACT_MODE_ABS);
Unload_Bitmap_File(&bitmap16bit);
*/


/////////////////Load flashing bars///////////

/*Create_Bitmap(&Intro_FlashingBar,100,100,34,8, SCREEN_BPP);
Intro_FlashingBar.attr |= BITMAP_ATTR_LOADED;

// fill in the background
Load_Bitmap_File(&bitmap16bit, "red_bar.bmp");

// load the grass bitmap image
Load_Image_Bitmap16(&Intro_FlashingBar,&bitmap16bit,1,1,BITMAP_EXTRACT_MODE_ABS);
Unload_Bitmap_File(&bitmap16bit);
*/

// load the graphics for the bat
Load_Bitmap_File(&bitmap16bit, "StartExit.BMP");		//load image into memory

// now create the bug blaster bob
Create_BOB(&bobStartExit,0,0,83,56,2,
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM/*| BOB_ATTR_ANIM_ONE_SHOT*/,
           DDSCAPS_SYSTEMMEMORY, 0, 16);

// load in the frames of the start exit text image
for (int index=0; index<2; index++)
     Load_Frame_BOB16(&bobStartExit,&bitmap16bit,index,index,0,BITMAP_EXTRACT_MODE_CELL);  //extract images from bitmap file and load into bob struct

Unload_Bitmap_File(&bitmap16bit);

Set_Pos_BOB(&bobStartExit,330,220);

Load_Animation_BOB(&bobStartExit,0,2,startExit_anim);



// lock the back buffer
DDraw_Lock_Back_Surface();

Draw_Bitmap16(&Intro_Text_AjMax, back_buffer, back_lpitch, 0);
//Draw_Bitmap16(&Intro_Text_Start, back_buffer, back_lpitch, 0);
//Draw_Bitmap16(&Intro_FlashingBar, back_buffer, back_lpitch, 0);

// unlock the back buffer
DDraw_Unlock_Back_Surface();

	Animate_BOB(&bobStartExit);

Draw_BOB16(&bobStartExit,lpddsback);

	DDraw_Flip();


/*
while (true)
	{
	// get joystick data
	lpdijoy->Poll(); // this is needed for joysticks only
	lpdijoy->GetDeviceState(sizeof(DIJOYSTATE), (LPVOID)&joy_state);

Draw_BOB(&bobStartExit,lpddsback);

//if (joy_state.lY != 0 )
//	{
//	Animate_BOB(&bobStartExit);
//	}

// check of user is trying to exit
if (KEY_DOWN(VK_ESCAPE) || KEY_DOWN(VK_SPACE))
    PostMessage(main_window_handle, WM_DESTROY,0,0);

	DDraw_Flip();

	}
*/


Sleep(5000);

// clear out buffers
DDraw_Fill_Surface(lpddsback, 0);
DDraw_Fill_Surface(lpddsprimary, 0);


} // end Do_Intro